hautomation-restclient
==================

REST client for sending home automation commands to django-hautomation REST API

This project belongs to the Home Automation Python Project, the url is: 

http://blog.digitalhigh.es/home-automation-python-project/

Further documentation about this module is found at:

http://blog.digitalhigh.es/home-automation-python-project/hautomation_restclient/


TESTING THE CODE
----------------

Please start a django_hautomation server at any reachable place.

Edit constants in hautomation_restclient/tests.py to configure the url and credentials
for the previously started django_hautomation server.

Then start the command: python hautomation_restclient/tests.py